==> s-group-form-0.0.976.tgz: package/src/mixins/form.item.js <==
import utils from '../utils'

export default {
  provide () {
    return {
      mapper: this.mapper,
      config: this.config
    }
  },
  data () {
    return {}
  },
  props: {
    formData: Object,
    value: String | Number,
    config: Object,
    itemStyle: Object,
    props: Object
  },
  computed: {
    mapper () {
      return Object.assign(
        this.props.mapper || {
          label: 'label',
          value: 'value',
          children: 'children'
        },
        this.config.mapper
      )
    },
    style () {
      const itemStyle = utils.lodash.cloneDeep(this.itemStyle)
      if (this.config.style) {
        return utils.lodash.merge(itemStyle, this.config.style)
      } else {
        return itemStyle
      }
    },
    model: {
      set (val) {
        if (this.config.props && !this.config.props.multiple && Array.isArray(val)) {
          const current = utils.lodash.difference(val, this.value)
          this.$emit('setValue', this.config.key, current)
        } else {
          this.$emit('setValue', this.config.key, val)
        }
      },
      get () {
        return this.value
      }
    }
  },
  methods: {
    change (value) {
      if (this.config.change) {
        this.config.change(this.config, value, this.formData)
      }
    },
    focus () {
      if (this.config.focus) {
        this.config.focus(this.config, this.value, this.formData)
      }
    },
    blur () {
      if (this.config.blur) {
        this.config.blur(this.config, this.value, this.formData)
      }
    }
  }
}

==> s-group-form-0.0.996.tgz: package/src/mixins/form.item.js <==
import utils from '../utils'

export default {
  provide () {
    return {
      mapper: this.mapper,
      config: this.config
    }
  },
  data () {
    return {}
  },
  props: {
    formData: Object,
    value: String | Number,
    config: Object,
    itemStyle: Object,
    props: Object
  },
  computed: {
    mapper () {
      return Object.assign(
        this.props.mapper || {
          label: 'label',
          value: 'value',
          children: 'children'
        },
        this.config.mapper
      )
    },
    style () {
      const itemStyle = utils.lodash.cloneDeep(this.itemStyle)
      if (this.config.style) {
        return utils.lodash.merge(itemStyle, this.config.style)
      } else {
        return itemStyle
      }
    },
    model: {
      set (val) {
        if (this.config.props && !this.config.props.multiple && Array.isArray(val)) {
          const current = utils.lodash.difference(val, this.value)
          this.$emit('setValue', this.config._code, this.config.key, current)
        } else {
          this.$emit('setValue', this.config._code, this.config.key, val)
        }
      },
      get () {
        return this.value
      }
    }
  },
  methods: {
    change (value) {
      if (this.config.change) {
        this.config.change(this.config, value, this.formData)
      }
    },
    focus () {
      if (this.config.focus) {
        this.config.focus(this.config, this.value, this.formData)
      }
    },
    blur () {
      if (this.config.blur) {
        this.config.blur(this.config, this.value, this.formData)
      }
    }
  }
}
